@@ -175,13 +175,13 @@ static int ctrlfile = -1;	/* Control file file-descriptor */
  *              MKREQ_INVALIDACC  Invalid account ID.
  *
  */
-int mkctrl (rawreq, reqtype, ptrfile, workdir, local_mid)
-register struct rawreq *rawreq;	/* Pointer to raw request structure. */
-int reqtype;			/* Request type: RTYPE_BATCH, RTYPE_DEVICE */
-FILE **ptrfile;			/* Ptr to FILE structure for data file */
-char *workdir;			/* Ptr to where to return ptr to the */
+int mkctrl (
+	struct rawreq *rawreq,	/* Pointer to raw request structure. */
+	int reqtype,		/* Request type: RTYPE_BATCH, RTYPE_DEVICE */
+	FILE **ptrfile,		/* Ptr to FILE structure for data file */
+	char *workdir,		/* Ptr to where to return ptr to the */
 				/* caller's original working directory */
-Mid_t *local_mid;		/* Machine-id of local host */
+	Mid_t *local_mid)	/* Machine-id of local host */
 {
 
 	char path [MAX_PATHNAME+1];
@@ -535,8 +535,7 @@ BAD SYSTEM TYPE
  *	       -1 if open error or fdopen() error.
  *	       -2 if too many data files would exist.
  */
-int mkdata (ptrfile)
-FILE **ptrfile;			/* Ptr to FILE structure for data file */
+int mkdata (FILE **ptrfile)
 {
 	char path [MAX_PATHNAME+1];		/* Pathname of data file */
 	int fd;
@@ -628,8 +627,7 @@ void zapreq()
  *		   references diagnostic text).  ALL request files 
  *		   describing the request are deleted.
  */
-long quereq (transaction_code)
-long *transaction_code;			/* Transaction completion code */
+long quereq (long *transaction_code)
 {
 	struct rawreq rawreq;		/* Raw request structure for just */
 					/* submitted request */
@@ -713,8 +711,7 @@ long *transaction_code;			/* Transaction completion code */
  *	Initialize a quota limit field to an appropriate default
  *	value that is valid when read by ../lib/readreq.c.
  */
-static void set_default_quota (quotafield)
-struct quotalimit *quotafield;			/* Field to be initialized */
+static void set_default_quota (struct quotalimit *quotafield)
 {
 	quotafield->max_units = QLM_BYTES;	/* Default units */
 	quotafield->warn_units = QLM_BYTES;
@@ -733,8 +730,7 @@ struct quotalimit *quotafield;			/* Field to be initialized */
  *           -1 if symlink error.
  *           -2 if too many data files would exist.
  */
-int mklink (datapath)
-char *datapath;                       /* Ptr to pathname of data file */
+int mklink (char *datapath)
 {
       char path [MAX_PATHNAME+1];             /* Pathname of data file */
       int i;
