@@ -151,9 +151,7 @@ BAD SYSTEM TYPE
  *		 0: if successful.
  *		-1: if unsuccessful (errno has reason).
  */
-int setmtime (path, ulongval)
-char *path;				/* Pathname of file */
-unsigned long ulongval;			/* Unsigned long mtime value */
+int setmtime (char *path, unsigned long ulongval)
 {
 #if	BSD43 | ULTRIX | DECOSF
 	struct timeval utimbuf [2];	/* Utimes() buffer */
