@@ -204,7 +204,7 @@ struct nlist anlist;
 #define X_CP_TIME       5
 #define X_MPID          6
 
-#ifndef hp9000s300
+#ifndef __hp9000s300
 #define X_HZ            7
 #endif
 
@@ -2777,7 +2777,7 @@ static summary(
        exit(1);
     }
     if (!nlist_flag) {
-#ifdef hp9000s800
+#ifdef __hp9000s800
         /* 800 names don't have leading underscores */
         for (i = 0; nlst[i].n_name; nlst[i++].n_name++)
             continue;
@@ -2808,10 +2808,11 @@ static summary(
 
     (void) getkval(proc, (int *)pbase, bytes, "proc array");
     for (i = 0; i < nproc; ++i) {
-        if (pstat(PSTAT_PROC, &pst[i], sizeof(pst[i]), 0, pbase[i].p_pid) != 1)
+        pst[i].pst_status=(struct pst_status *)malloc(sizeof(struct pst_status));
+        if (pstat(PSTAT_PROC, pst[i], sizeof(struct pst_status), 0, pbase[i].p_pid) != 1)
 	           pbase[i].p_upreg = (preg_t *) 0;
         else
-            pbase[i].p_upreg = (preg_t *) &pst[i];
+            pbase[i].p_upreg = (preg_t *) pst[i].pst_status;
         pbase[i].p_nice = pst[i].pst_status->pst_nice;
         pbase[i].p_cpticks = pst[i].pst_status->pst_cpticks;
     }
@@ -2907,6 +2908,8 @@ getkval(
     return(1);
 }
 
+#endif
+
 #if SOLARIS
 #define PROCFS "/proc"
  
