@@ -124,22 +124,20 @@ static long tell_nqs_scheduler (/* int orig_seqno, Mid_t orig_mid, struct reques
  *	Process an NQS request completion event.
  */
 #if	HPUX | SGI | SYS52 | IBMRS | SOLARIS | LINUX
-void nqs_reqcom (orig_seqno, orig_mid, exitcode, tms, queuename)
-long orig_seqno;			/* Request original sequence# */
-Mid_t orig_mid;				/* Request original machine-id */
-int exitcode;				/* Exit code */
-struct tms *tms;			/* CPU time usage by request */
-char *queuename;			/* Queuename for which request */
-					/* is reporting an exit code */
+void nqs_reqcom (
+ 	long orig_seqno,		/* Request original sequence# */
+ 	Mid_t orig_mid,			/* Request original machine-id */
+ 	int exitcode,			/* Exit code */
+ 	struct tms *tms,		/* CPU time usage by request */
+ 	char *queuename)		/* Queuename for which request */
 #else
 #if	BSD43 | ULTRIX | DECOSF
-void nqs_reqcom (orig_seqno, orig_mid, exitcode, rusage, queuename)
-long orig_seqno;			/* Request original sequence# */
-Mid_t orig_mid;				/* Request original machine-id */
-int exitcode;				/* Exit code */
-struct rusage *rusage;			/* Resource utilization by request */
-char *queuename;			/* Queuename for which request */
-					/* is reporting an exit code */
+void nqs_reqcom (
+ 	long orig_seqno,		/* Request original sequence# */
+ 	Mid_t orig_mid,			/* Request original machine-id */
+ 	int exitcode,			/* Exit code */
+ 	struct rusage *rusage,		/* Resource utilization by request */
+ 	char *queuename)		/* Queuename for which request */
 #else
 BAD SYSTEM TYPE
 #endif
@@ -632,8 +630,7 @@ BAD SYSTEM TYPE
  *	The NQS database image of the server queue is NOT updated
  *	by this function.
  */
-static void requeue (req)
-register struct request *req;			/* Request to requeue */
+static void requeue (struct request *req)
 {
 
 	register struct nqsqueue *serverq;		/* Request queue */
@@ -670,8 +667,7 @@ register struct request *req;			/* Request to requeue */
  *	void stopallqueues():
  *	Stop all NQS queues.
  */
-static void stopallqueues (serverq)
-register struct nqsqueue *serverq;	/* Queue containing exited req */
+static void stopallqueues (struct nqsqueue *serverq)
 {
 	register struct nqsqueue *queue;
 
@@ -716,9 +712,9 @@ register struct nqsqueue *serverq;	/* Queue containing exited req */
  *	device was the last device enabled in the queue/device set
  *	for the server queue.
  */
-static void stopdev (device, serverq)
-register struct device *device;		/* Device to be marked as failed */
-register struct nqsqueue *serverq;	/* Queue that was being handled by */
+static void stopdev (
+	struct device *device,		/* Device to be marked as failed */
+	struct nqsqueue *serverq)	/* Queue that was being handled by */
 					/* the device */
 {
 	register struct qdevmap *map;	/* Walk queue/device mappings */
@@ -764,11 +760,11 @@ register struct nqsqueue *serverq;	/* Queue that was being handled by */
  * scheduler to see if anything can run on that system.
  */
 long
-nqs_rreqcom(client_mid,  req_mid,  req_seqno,  no_jobs)
-Mid_t	client_mid;		/* Mid that is reporting completion */
-Mid_t	req_mid;		/* Mid of request which completed */
-int	req_seqno;		/* Seqno of request which completed */
-int	no_jobs;		/* Remaining number of jobs */
+nqs_rreqcom(
+	Mid_t	client_mid,	/* Mid that is reporting completion */
+	Mid_t	req_mid,	/* Mid of request which completed */
+	int	req_seqno,	/* Seqno of request which completed */
+	int	no_jobs)	/* Remaining number of jobs */
 {
     struct loadinfo *load_ptr;       /* Load information pointer */
 
@@ -794,11 +790,10 @@ int	no_jobs;		/* Remaining number of jobs */
  * Send a message back to the NQS scheduler node that we have completed
  * a request.
  */
-static long
-tell_nqs_scheduler(orig_seqno, orig_mid, request)
-int orig_seqno;
-Mid_t orig_mid;
-struct request *request;
+static long tell_nqs_scheduler(
+	int orig_seqno,
+	Mid_t orig_mid,
+	struct request *request)
 {
 
     struct passwd *whompw;           /* Whose request it is */
